mysql.stmt.bind_in.In_Blob

Package mysql :: Package stmt :: Module bind_in :: Class In_Blob |
[hide private]
[frames] | no frames]

# Class In_Blob

    object --+
             |
    Input_Bind --+
                 |
    Base_In_Stream --+
                     |
                    In_Blob

BLOB input binding.

The constructor takes the following arguments:

- `who`: The object from which to read the value.
- `what`: The name of the parameter in the object to read.
- `use_stream`: If True, sets `who.what` to a stream object (Input_Stream) that has a `write` method. If False, then it assumes the value is just a string. Defaults to False.

Note that In_Text is an alias for this object.

Instance Methods | [hide private]
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `Base_In_Stream`: `__init__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e5c0>`

Instance Variables | [hide private]
Inherited from `Base_In_Stream` (private): `_max_size`, `_param_num`, `_raise_error`, `_stmt`, `_stream`, `_use_stream` Inherited from `Input_Bind` (private): `_buffer`, `_buffer_length`, `_buffer_type`, `_is_null`, `_is_unsigned`, `_length`, `_what`, `_who`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: Base_In_Stream.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e5c0>